#!/bin/bash

#Logging Function
SCRIPT=update-stratux-cp2102.sh
STX_LOG="/var/log/stratux.log"
function wLog () {
	echo "$(date +"%Y/%m/%d %H:%M:%S")  - $SCRIPT - $1" >> ${STX_LOG}
}

cd /etc/udev/rules.d

rules=10-stratux.rules

# If a connected device has been programmed as "Stratux Serialout" then it should take over serialout0.
# Modify the official Stratux image rule.
# Replace %n with 0 because the Stratux software doesn't look for anything but 0 anyway.
# Use link_priority=100 to make sure this rule wins the link for serialout0 if it matches.
before='^SUBSYSTEMS=="usb", ATTRS{interface}=="Stratux Serialout", SYMLINK+="serialout.*$'
after='SUBSYSTEMS=="usb", ATTRS{interface}=="Stratux Serialout", SYMLINK+="serialout0", OPTIONS+="link_priority=100"'
if ! grep -q "link_priority=100" $rules; then
	wLog "Updated official serialout link"
	sed -i "s/$before/$after/" $rules
fi

# Use a generic CP2102 adapter that hasn't been programmed.  This conflicts with softrf.
if ! grep -q '10c4.*ea60.*serialout' $rules; then
	wLog "Configured to accept all CP2102 devices for serialout"
	echo 'SUBSYSTEMS=="usb", ATTRS{idVendor}=="10c4", ATTRS{idProduct}=="ea60", SYMLINK+="serialout0", OPTIONS+="link_priority=1"' >> $rules
fi
