#!/bin/bash

#Logging Function
SCRIPT=update-stratux-guc232a.sh
STX_LOG="/var/log/stratux.log"
function wLog () {
	echo "$(date +"%Y/%m/%d %H:%M:%S")  - $SCRIPT - $1" >> ${STX_LOG}
}

cd /etc/udev/rules.d

rules=10-stratux.rules

# If a connected device has been programmed as "Stratux Serialout" then it should take over serialout0.
# Modify the official Stratux image rule.
# Replace %n with 0 because the Stratux software doesn't look for anything but 0 anyway.
# Use link_priority=100 to make sure this rule wins the link for serialout0 if it matches.
before='^SUBSYSTEMS=="usb", ATTRS{interface}=="Stratux Serialout", SYMLINK+="serialout.*$'
after='SUBSYSTEMS=="usb", ATTRS{interface}=="Stratux Serialout", SYMLINK+="serialout0", OPTIONS+="link_priority=100"'
if ! grep -q "link_priority=100" $rules; then
	wLog "Updated official serialout link"
	sed -i "s/$before/$after/" $rules
fi

# Add serialout0 symlink for IOGear GUC232A.
if ! grep -q '0557.*2008.*serialout' $rules; then
	wLog "Configured to accept ATEN PL2303 devices (IOGear GUC232A) for serialout"
	echo 'SUBSYSTEMS=="usb", ATTRS{idVendor}=="0557", ATTRS{idProduct}=="2008", SYMLINK+="serialout0", OPTIONS+="link_priority=2"' >> $rules
fi
