#!/bin/bash

#Logging Function
SCRIPT=update-stratux-tu-s9.sh
STX_LOG="/var/log/stratux.log"
function wLog () {
	echo "$(date +"%Y/%m/%d %H:%M:%S")  - $SCRIPT - $1" >> ${STX_LOG}
}

cd /etc/udev/rules.d

rules=10-stratux.rules

# If a connected device has been programmed as "Stratux Serialout" then it should take over serialout0.
# Modify the official Stratux image rule.
# Replace %n with 0 because the Stratux software doesn't look for anything but 0 anyway.
# Use link_priority=100 to make sure this rule wins the link for serialout0 if it matches.
before='^SUBSYSTEMS=="usb", ATTRS{interface}=="Stratux Serialout", SYMLINK+="serialout.*$'
after='SUBSYSTEMS=="usb", ATTRS{interface}=="Stratux Serialout", SYMLINK+="serialout0", OPTIONS+="link_priority=100"'
if ! grep -q "link_priority=100" $rules; then
	wLog "Updated official serialout link"
	sed -i "s/$before/$after/" $rules
fi

# Use a generic PL2303 adapter for serialout.  This conflicts with the BU-353-S4 GPS and maybe others.

# First, disable prolific symlinks to prevent them from being opened as a GPS.
if grep -q "^S.*prolific" $rules; then
	wLog "Configured to ignore PL2303 devices for GPS"
	sed -i 's/^S.*prolific/#&/' $rules
fi
# Add serialout0 symlink.
if ! grep -q '067b.*2303.*serialout' $rules; then
	wLog "Configured to accept all PL2303 2303 devices for serialout"
	echo 'SUBSYSTEMS=="usb", ATTRS{idVendor}=="067b", ATTRS{idProduct}=="2303", SYMLINK+="serialout0", OPTIONS+="link_priority=2"' >> $rules
fi
if ! grep -q '067b.*23c3.*serialout' $rules; then
	wLog "Configured to accept all PL2303 23c3 devices for serialout"
	echo 'SUBSYSTEMS=="usb", ATTRS{idVendor}=="067b", ATTRS{idProduct}=="23c3", SYMLINK+="serialout0", OPTIONS+="link_priority=3"' >> $rules
fi
